# [WaveletAI](market.xiaobodata.com) <img src="http://oss.xiaobodata.com/public/product/logo/wai.png" width="45" />
<a href="http://gitlab.xiaobodata.com/FirstGroup/WAI/waveletai/-/commits/master"><img alt="pipeline status" src="http://gitlab.xiaobodata.com/FirstGroup/WAI/waveletai/badges/master/pipeline.svg" /></a>
<a href="http://gitlab.xiaobodata.com/FirstGroup/WAI/waveletai/-/commits/master"><img alt="coverage report" src="http://gitlab.xiaobodata.com/FirstGroup/WAI/waveletai/badges/master/coverage.svg" /></a>

A Machine Learning Lifecycle Platform for AI/ML individuals and teams. 



小波AI是一个集合数据、编程、模型、算力、服务的一站式协同开发云平台，提供全栈的AI能力。

在这里，你可以根据业务需要，轻松的来训练、部署、管理和跟踪你的模型。

小波AI已在服务于微企多个团队，稳定运行了一年，大大加速了AI项目的实施和推进速度，目前在平台已经完成了上百种模型的前期验证、训练和发布，并在AI市场中发布了多种能力。



> Power By [WaveletPlus](http://plus.xiaobodata.com/) <img src="http://oss.xiaobodata.com/public/product/logo/wavelet_plus.png" width="45" />

## 功能特性

### 全生命周期跟踪

- 小波AI会自动关联跟踪记录模型运行时信息，记录训练过程状态和运行数据，支持自定义参数、指标设置并生成实时日志，帮助你快速进行试验，验证想法；

- 小波AI支持完全支持用于跟踪工作的 Git 存储库(支持HTTP/SSH双协议)，在向小波AI提交模型训练时，系统会将有关存储库的信息作为训练过程的一部分进行跟踪；

![git-support](http://plus.xiaobodata.com/wai_doc/static/img/git-support.png)

### 丰富的AI套件支持

小波AI平台可用于任何类型的机器学习，从传统 ml 到深度学习、监督式和非监督式学习。无论你是否希望编写 Python 或 R 代码，你都可以在小波AI中构建、训练和跟踪你的模型。

该平台还可与常用的AI套件快速集成（如 PyTorch、TensorFlow 、keras、xgboost、 scikit-learn、lightgbm、spark、onnx等）。

![ai](http://plus.xiaobodata.com/wai_doc/static/img/2020-06-17-09-52-04.png)

### 为大型项目协作而生

- 小波AI适用于大型项目开发场景，让你从大量的离线作业中脱身出来，不同角色得人都可以在平台中实现快速协作；

- 用DevOps的方式管理你的ML工作，从开发到部署的自动流程化实现。大大降低模型迭代开发及部署实施的难度；

- 提供强有力的设备算力支持和资源分配策略，让你可以在CPU、GPU设备上快速训练；

- 通用权限设计，满足组内成果共享和组间权限控制等实际场景，让多项目并行管理不再困难；

- 无需调整业务应用接口，支持模型版本的在线更新；

### 在任何地方以相同方式运行

- 小波AI 会将项目模型打包为再任何平台上可重现的模式；

- 一键发布模型，快速实现模型的云端和终端设备部署；


## 帮助信息

* 帮助手册 [documentation](http://plus.xiaobodata.com/wai_doc/),

* 介绍视频 [video tutorials](https://player.youku.com/embed/XNDcyNDI1OTg5Mg==),

* 发送邮件至 [weveletplus@visionet.com.cn](mailto:weveletplus@visionet.com.cn)

## 团队

@Author  : WaveletAI-Product-Team

@license : (C) Copyright 2019-2022, Visionet(Tianjin)Information Technology Co.,Ltd.